nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Pid

Struct Pid 

#[repr(transparent)]
pub struct Pid(pub u32);
Peripheral identification register.

Tuple Fields

0: u32

Implementations

Source

impl Pid

pub const fn aperture(&self) -> u8

size aperture for the register port on the bus (APB or AHB).

pub const fn set_aperture(&mut self, val: u8)

size aperture for the register port on the bus (APB or AHB).

pub const fn minor_rev(&self) -> u8

Minor revision of module implementation.

pub const fn set_minor_rev(&mut self, val: u8)

Minor revision of module implementation.

pub const fn major_rev(&self) -> u8

Major revision of module implementation.

pub const fn set_major_rev(&mut self, val: u8)

Major revision of module implementation.

pub const fn id(&self) -> u16

Module identifier for the selected function.

pub const fn set_id(&mut self, val: u16)

Module identifier for the selected function.